#
# spec file for package ghc-pandoc-types
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name pandoc-types
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.17.5.4
Release:        1.1
Summary:        Types for representing a structured document
License:        GPL-2.0-only
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-string-qq-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif

%description
'Text.Pandoc.Definition' defines the 'Pandoc' data structure, which is used by
pandoc to represent structured documents. This module used to live in the
pandoc package, but starting with pandoc 1.7, it has been split off, so that
other packages can use it without drawing in all of pandoc's dependencies, and
pandoc itself can depend on packages (like citeproc-hs) that use them.

'Text.Pandoc.Builder' provides functions for building up 'Pandoc' structures
programmatically.

'Text.Pandoc.Generic' provides generic functions for manipulating Pandoc
documents.

'Text.Pandoc.Walk' provides faster, nongeneric functions for manipulating
Pandoc documents.

'Text.Pandoc.JSON' provides functions for serializing and deserializing a
'Pandoc' structure to and from JSON.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc changelog

%changelog
* Mon Oct 29 2018 psimons@suse.com
- Update pandoc-types to version 1.17.5.4.
  [1.17.5.4]
  * Put NFData in scope for ghc < 7.10.
  * Reduce deepseq lower bound for ghc < 7.10.
* Mon Oct 22 2018 psimons@suse.com
- Update pandoc-types to version 1.17.5.3.
  [1.17.5.3]
  * For ghc < 7.10, constrain deepseq-generics to >= 0.2, which no
    longer exprots NFData from deepseq. Add deepseq dependency.
* Sat Oct 20 2018 psimons@suse.com
- Update pandoc-types to version 1.17.5.2.
  [1.17.5.2]
  * Bump upper bound for deepseq-generics, QuickCheck, criterion.
  * Implement QuickCheck shrinking for Inlines and Blocks (Alexander Krotov).
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update pandoc-types to version 1.17.5.1.
  [1.17.5.1]
  * Declare the ToMetaValue instance for String as OVERLAPPING (#46).
  [1.17.5]
  * Bump upper bounds for aeson, base.
  * Allow building on older ghc versions (George Wilson).
  * Text.Pandoc.Arbitrary: generate SoftBreaks and LineBreaks
    (Alexander Krotov).
  * Pad table rows up to maximum row length, to guarantee that
    all rows have the same number of columns
    (see jgm/pandoc#4059, Francesco Occhipinti).
  * Make String an instance of ToMetaValue (Alexander Krotov).
* Mon May 14 2018 psimons@suse.com
- Update pandoc-types to version 1.17.4.2 revision 1.
  * Import Semigroups when needed rather than using CPP.
  * Bump criterion upper bound.
  * Add Semigroup instances for Pandoc, Meta, Inlines, Blocks
    (if base >= 4.9).  This is needed for the library to compile
    with ghc 8.4.
  * Bumped criterion upper bound.
  * Bumped upper bounds for criterion and QuickCheck.
  * Added Walkable instances for `[Inline] Inline` and `[Block] Block`.
  * Provide default implementation for walk (Albert Krewinkel).
    The implementations for `walk` and `walkM` are very similar, so a
    default method is provided which implements the former in terms of the
    latter. This change should not affect performance, as the `Identity`
    functor, which is used in the default definition, is a newtype that
    should be eliminated at compile time.  (This requires a dependency
    on transformers for ghc 7.8.x.)
  * Force optimizations when compiling Walk module (Albert Krewinkel).
  * Add `Applicative m` to the context of walkM (Albert Krewinkel).
    The acceptance of AMP makes this a natural change.
  * Add `Walkable [Block]` and `Walkable [Inline]` instances (Albert
    Krewinkel).
  * Factored out duplicate code in Walk.
  * Added benchmark.
  * Text.Pandoc.JSON: Use `walk` instead of `bottomUp` in the
    `ToJSONFilter` instance for `a -> [a]`.  Note that behavior will be
    slightly different, since bottomUp's treatment of a function `[a] -> [a]`
    is to apply it to each sublist of a list, while walk applies it only to
    maximal sublists.  Usually the latter behavior is what is wanted, and the
    former can be simulated when needed.  But there may be existing filters
    that need to be rewritten in light of the new behavior.
  * Better consistency in simpleTable and table (jgm/pandoc#3648).
    If `headers` is empty, we populate it with empty cells, using the rows
    to determine number of columns.  We also ensure that there are numcols
    alignments and column widths.
  * Make sure Div and Span occur in Arbitrary instances.
  * Bump dependency upper bounds.
  * Removed unused mapConst.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 1.17.0.5 revision 4.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 1.17.0.5 revision 3 with cabal2obs.
* Wed Mar 22 2017 psimons@suse.com
- Update to version 1.17.0.5 revision 2 with cabal2obs.
* Thu Mar  2 2017 psimons@suse.com
- Update to version 1.17.0.5 revision 1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.17.0.5 with cabal2obs.
* Sun Aug 21 2016 psimons@suse.com
- Update to version 1.16.1.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.16.1 revision 0 with cabal2obs.
* Thu Feb 11 2016 mimi.vx@gmail.com
-  update to 1.16.1
  * Export pandocTypesVersion from Text.Pandoc.Definition.
* Sat Jan 23 2016 mimi.vx@gmail.com
- update to 1.16.0.1
  * Added Attr field to Image and Link.
  * Added SoftBreak constructor to Inline
* Sun Sep 27 2015 mimi.vx@gmail.com
- update to 1.12.4.7
* Sun Jul 19 2015 mimi.vx@gmail.com
- update to 1.12.4.5
* Mon Jun  8 2015 mimi.vx@gmail.com
- update to 1.12.4.4
* Sun May 31 2015 mimi.vx@gmail.com
- change license file to COPYING
* Sun May 31 2015 mimi.vx@gmail.com
- update to 1.12.4.3
* Thu Apr 23 2015 mimi.vx@gmail.com
- update to 1.12.4.2
* Thu Mar 27 2014 sbahling@suse.com
- Correct package license
* Thu Mar 13 2014 sbahling@suse.com
- update to 1.12.3.2
* Tue Dec 31 2013 peter.trommler@ohm-hochschule.de
- update to 1.12.3
- needed for pandoc 1.12.2.1
* Sun Dec 29 2013 peter.trommler@ohm-hochschule.de
- merged d:l:haskell changes
* Mon Oct 21 2013 peter.trommler@ohm-hochschule.de
- merged defattr change from d:l:h
* Sun Sep 29 2013 sbahling@suse.com
- update to 1.12.1
* Tue May 14 2013 peter.trommler@ohm-hochschule.de
- new cabal-rpm spec file template
  * macros not spanning multiple spec file sections
* Fri Jan 25 2013 peter.trommler@ohm-hochschule.de
- update to 1.10 from upstream
- part of pandoc 1.10 release
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 template for spec file
* Tue Mar 13 2012 peter.trommler@ohm-hochschule.de
- rpmlint: filter debuginfo warning
* Mon Mar 12 2012 peter.trommler@ohm-hochschule.de
- upgrade to 1.9.1 from upstream
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
